@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/game.c,v 11.35 2007/05/22 13:38:37 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.0 2009/06/28 20:43:12 jcb Rel $
  * game.c
  * Routines for manipulating game data structures.
  */
@@ -14,7 +14,7 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/newmj/RCS/game.c,v 11.35 2007/05/22 13:38:37 jcb Exp $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.0 2009/06/28 20:43:12 jcb Rel $";
 
 #include "game.h"
 #include "sysdep.h"
@@ -131,6 +131,7 @@ static GameOptionEntry default_optiontable[] = {
   { GOLosersSettle, "LosersSettle", GOTBool, 0, 0, { 1 }, "losers pay each other", 0 },
   { GODiscDoubles, "DiscDoubles", GOTBool, 0, 0, { 0 }, "the discarder pays double", 0 },
   { GOShowOnWashout, "ShowOnWashout", GOTBool, 0, 0, { 0}, "tiles revealed on washout", 0 },
+  { GONumRounds, "NumRounds", GOTNat, 0, 0, { 4 }, "number of rounds to play", 0 },
   { GOEnd, "End" , GOTBool, 0, 0, { 1 }, "end of option list", 0 }
 };
 
@@ -1860,7 +1861,15 @@ int game_handle_cmsg(Game *g, CMsgMsg *cm)
     return 0;
   case CMsgPlayerOptionSet:
     /* This should be dealt with by client code, not us */
-    g->cmsg_err = "Player options are not dealt with by the game";
+    g->cmsg_err = "Player options are not dealt with by the game code";
+    return -1;
+  case CMsgAuthReqd:
+    /* This should be dealt with by client code, not us */
+    g->cmsg_err = "Authorization are not dealt with by the game code";
+    return -1;
+  case CMsgRedirect:
+    /* This should be dealt with by client code, not us */
+    g->cmsg_err = "Redirection is not dealt with by the game code";
     return -1;
   }
   /* if we get to here, we were passed a bad CMsg type, which should
