@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/newmj/RCS/protocol.h,v 11.18 2007/05/22 13:38:50 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/protocol.h,v 12.0 2009/06/28 20:43:13 jcb Rel $
  * protocol.h
  * defines the messages passed between players and controller
  */
@@ -76,6 +76,7 @@ typedef enum {
   GOLosersSettle, /* do losers pay among themselves? */
   GODiscDoubles, /* does the discarder pay a double score? */
   GOShowOnWashout, /* are tiles revealed after a washout? */
+  GONumRounds, /* how many rounds in a game? */
   GOEnd } GameOption;
 #define GONumOptions (GOEnd+1)
 
@@ -134,7 +135,7 @@ typedef struct _GameOptionEntry {
 */
 
 /* This define gives the protocol version implemented in this file */
-#define PROTOCOL_VERSION 1072
+#define PROTOCOL_VERSION 1101
 
 /* This global variable, found in protocol.c, is used by many functions
    to determine the protocol version currently being used.
@@ -163,6 +164,8 @@ typedef enum {
   CMsgStateSaved = 2,
   CMsgConnectReply = 10,
   CMsgReconnect = 11,
+  CMsgAuthReqd = 12,
+  CMsgRedirect = 13,
   CMsgPlayer = 20,
   CMsgNewRound = 29,
   CMsgGame = 30,
@@ -218,6 +221,9 @@ typedef enum {
   PMsgLoadState = 2,
   PMsgConnect = 10,
   PMsgRequestReconnect = 11,
+  PMsgAuthInfo = 12,
+  PMsgNewAuthInfo = 13,
+  PMsgDisconnect = 14,
   PMsgDeclareSpecial = 33,
   PMsgRequestPause = 36,
   PMsgReady = 37,
@@ -330,6 +336,40 @@ typedef struct _CMsgConnectReplyMsg {
   char *reason; /* human readable reason for refusal (if refused) */
 } CMsgConnectReplyMsg;
 
+/* Message sent by controller to request authentication.
+   This message was introduced at pversion 1100. */
+typedef struct _CMsgAuthReqdMsg {
+  ControllerMsgType type; /* CMsgAuthReqd */
+  word16 authtype; /* type of authorization, currenly just: basic */
+  char *authdata; /* any data to be included */
+} CMsgAuthReqdMsg;
+
+/* Message sent by player to provide authentication.
+   This message was introduced at pversion 1100. */
+typedef struct _PMsgAuthInfoMsg {
+  PlayerMsgType type; /* PMsgAuthInfo */
+  word16 authtype; /* type of authorization, currenly just: basic */
+  char *authdata; /* any data to be included */
+} PMsgAuthInfoMsg;
+
+/* Message sent by player to provide new authentication info.
+   This message was introduced at pversion 1100. */
+typedef struct _PMsgNewAuthInfoMsg {
+  PlayerMsgType type; /* PMsgNewAuthInfo */
+  word16 authtype; /* type of authorization, currenly just: basic */
+  char *authdata; /* any data to be included */
+} PMsgNewAuthInfoMsg;
+
+/* Message sent by controller to tell player to close connection
+   and connect to another port. The player should connect with
+   the same id and name that it currently has.
+   This message was introduced at pversion 1100. */
+typedef struct _CMsgRedirectMsg {
+  ControllerMsgType type; /* CMsgRedirect */
+  char *dest; /* new connection, in the standard form host:port.
+                 If host is omitted, use the same host. */
+} CMsgRedirectMsg;
+
 /* This message requests a "reconnection": that is, the equivalent
    of disconnecting and connection, without actually dropping the
    network connection. If a positive reply is received, the client's
@@ -347,6 +387,11 @@ typedef struct _CMsgReconnectMsg {
   ControllerMsgType type; /* CMsgReconnect */
 } CMsgReconnectMsg;
 
+/* This message is an explicit disconnect to quit the game.
+   This message was introduced at pversion 1100. */
+typedef struct _PMsgDisconnectMsg {
+  PlayerMsgType type; /* PMsgDisconnect */
+} PMsgDisconnectMsg;
 
 /* Message sent by controller to inform players of each other's existence.
    When a player connects, it receives one such message for every already
